Input

pub struct Input {
    pub activityDefinition: Option<ActivityDefinition>,
    pub subject: Vec<FHIRString>,
    pub encounter: Option<FHIRString>,
    pub practitioner: Option<FHIRString>,
    pub organization: Option<FHIRString>,
    pub userType: Option<CodeableConcept>,
    pub userLanguage: Option<CodeableConcept>,
    pub userTaskContext: Option<CodeableConcept>,
    pub setting: Option<CodeableConcept>,
    pub settingContext: Option<CodeableConcept>,
}

Fields

activityDefinition: Option<ActivityDefinition>

The activity definition to apply. If the operation is invoked on an instance, this parameter is not allowed. If the operation is invoked at the type level, this parameter is required

subject: Vec<FHIRString>

The subject(s) that is/are the target of the activity definition to be applied. The subject may be a Patient, Practitioner, Organization, Location, Device, or Group. Subjects provided in this parameter will be resolved as the subject of the PlanDefinition based on the type of the subject. If multiple subjects of the same type are provided, the behavior is implementation-defined

encounter: Option<FHIRString>

The encounter in context, if any

practitioner: Option<FHIRString>

The practitioner in context

organization: Option<FHIRString>

The organization in context

userType: Option<CodeableConcept>

The type of user initiating the request, e.g. patient, healthcare provider, or specific type of healthcare provider (physician, nurse, etc.)

userLanguage: Option<CodeableConcept>

Preferred language of the person using the system

userTaskContext: Option<CodeableConcept>

The task the system user is performing, e.g. laboratory results review, medication list review, etc. This information can be used to tailor decision support outputs, such as recommended information resources

setting: Option<CodeableConcept>

The current setting of the request (inpatient, outpatient, etc.)

settingContext: Option<CodeableConcept>

Additional detail about the setting of the request, if any